/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.davic.media;



/**

 * This interface is the base interface for both audio and subtitling language control. This 

 * interface should never be implemented in a control alone, but always either as audio or subtitling 

 * language control. If a language can not be selected because the user/application is not entitled to 

 * access it, the language is reset to that before the invocation of the method.

 * If more than one stream with the same language exists, the behaviour of 

 * selectLanguage(String)is to select the first listed in the network signalling. 

 * NOTE:This is equivalent to item b under 11.4.2.3,"Default media player behaviour".

 */

public interface LanguageControl extends javax.media.Control

{

	/**

	 * Provides the application a list of available languages.

	 * The returned strings contain three letter language codes according to ISO 639 standard.

	 * If there are no selectable languages, the method returns an array of length zero.

	 */

	public String[] listAvailableLanguages();



	/**
	 * Changes the language to the language given in the parameter. 
	 * When this method returns normally, the language will have been synchronously selected.
	 *
	 * @param lang the desired language code according to the ISO 639 standard.
	 * @exception LanguageNotAvailableException if the language given in the parameter is not available, 
	 * @exception org.davic.media.NotAuthorizedException if access to the required language is not 
	 * permitted
	*/

	public void selectLanguage(String lang) throws LanguageNotAvailableException, 

		org.davic.media.NotAuthorizedException;



	/**
	 * Returns the language code of the currently selected language. 
	 * If no content of the appropriate media type for the control is present,
	 * a String of length zero is returned.
	 */

	public String getCurrentLanguage();



	/**

	 * Changes the language to the default language determined by the implementation.
	 * If no content of the appropriate media type for the control is present,
	 * a String of length zero is returned.

	 * @return the language code of the default language.

	 * @exception org.davic.media.NotAuthorizedException  If access to the default language is not 

	 * permitted

	*/

	public String selectDefaultLanguage() throws org.davic.media.NotAuthorizedException;

}
