/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.dvb.application ;



/**

 * A <code>DVBHTMLProxy</code> Object is a proxy to a DVBHTML application.

 */

public interface DVBHTMLProxy extends AppProxy {

	/**

	 * The application is in the loading state.

	 * @since MHP 1.0.2

	 */

	public static final int LOADING = 6;

	/**

	 * The application is in the killed state.

	 * @since MHP 1.0.2

	 */

	public static final int KILLED = 7;





    /**

     * Loads the initial entry page of the application and waits for a signal. 

     * This method mimics the PREFETCH control code and is intended to be 

     * called instead of

     * and not as well as start. Calling prefetch on a started application will

     * have no effect.

     *

     * @throws SecurityException if the calling application does not have 

     * permission to start applications

     * @since   MHP1.0

     */

    public void prefetch () ;

    

    /**

     * Sends the application a start trigger at the specified time. 

     *

     * @param starttime the specified time to send a start trigger to the application. If the time

     * has already passed the application manager shall send the trigger 

     * immediately. Dates pre-epoch shall always cause the application manager 

     * to send the trigger immediately.

     * @throws SecurityException if the calling application does not have 

     * permission to start applications

     *

     * @since   MHP1.0

     */

    public void startTrigger (java.util.Date starttime) ;



    /**

     * Sends the application a trigger with the given payload at the specified time. 

     *

     * @param time the specified time to send a start trigger to the application. 

If the time has

     * already passed the application manager should send the trigger 

     * immediately. Dates pre-epoch shall always cause the application manager

     * to send a 'now' trigger.

     *

     * @param triggerPayload the specified payload to deliver with the trigger. 

     * The payload is specified as object, but this 

     * will be refined once DVB-HTML Triggers are properly defined.

     * @throws SecurityException if the calling application does not have 

     * permission to start applications

     *

     * @since   MHP1.0

     */

    public void trigger (java.util.Date time, Object triggerPayload) ;

}




