/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.dvb.application;

/**
 * A <code>DVBJProxy</code> Object is a proxy to a DVBJ application.
 */
public interface DVBJProxy extends AppProxy{

	/**
	 * The application is in the loaded state. 
	 */
	 public static final int LOADED = 5;


    /**
     * Provides a hint to preload at least the initial class of the application
     * into local storage, resources permitting. This does not require loading of
     * classes into the virtual machine or creation of a new logical virtual
     * machine which are implications of the <code>init</code> method.
     * <p>This method is asynchronous and its completion will be notified by 
     * an <code>AppStateChangeEvent</code>. In case of failure, the <code>hasFailed</code>
     * method of the <code>AppStateChangeEvent</code> will return true.
     * Calls to this method shall only succeed if the application is in the
     * NOT_LOADED state.
     * In all cases, an AppStateChangeEvent will be sent, whether 
     * the call was successful or not.
     * @since   MHP1.0
     * @throws SecurityException if the application is not entitled to load
     *  	this application. Being able to load an application requires
     *		to be entitled to start it.

     */
    public void load ();
    
    /**
     * Requests the application manager calls the <code>initXlet</code> method on 
     * the application.
     * <p>This method is asynchronous and its completion will be notified by 
     * an AppStateChangeEvent. In case of failure, the hasFailed method of 
     * the <code>AppStateChangeEvent</code> will return true. 
     * Calls to this method shall only succeed if the application is in the
     * NOT_LOADED or LOADED states. If the application is in the NOT_LOADED
     * state, the application will move through the LOADED state into the PAUSED
     * state before calls to this method complete.
     * <p> In all cases, an AppStateChangeEvent will be sent, whether the call 
     * was successful or not.
     * @throws SecurityException if the application is not entitled to load
     *  	this application. Being able to init an application requires
     *		to be entitled to start it.
     *
     * @since   MHP1.0
     */
    public void init () ;
}


