/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.dvb.dsmcc;

/**
 * Sent when an MHP terminal detects a permanent discontinuity in NPT
 * as defined in the main body of the present document. This represents an 
 * error condition in the incoming broadcast.<p>
 * This event shall be sent following a PCR discontinuity when the MHP
 * terminal has enough information to determine that there will be an
 * NPT discontinuity. If the <code>NPTDiscontinuityEvent</code> is because of invalid data in a new
 * NPTReferenceDescriptor then the event will be generated when that
 * new NPTReferenceDescriptor is detected by the MHP terminal. If the <code>NPTDiscontinuityEvent</code>
 * is because no new NPTReferenceDescriptor is detected within the time
 * allowed by the main body of the present document then it will be generated
 * when that time interval has elapsed.
 * @since MHP 1.0.1
 */

public class NPTDiscontinuityEvent extends NPTStatusEvent {
	/**
	 * Construct an event. The <code>before</code> and <code>after</code> values 
	 * used shall be the values at the time when the receiver determined that a
	 * NPT discontinuity has happened. If the <code>NPTDiscontinuityEvent</code> is because of invalid data in a
 	 * new NPTReferenceDescriptor then this is the time when that new
	 * descriptor was known to be invalid. If <code>NPTDiscontinuityEvent</code> is because of the absence of
	 * a new NPTReferenceDescriptor then this will be when the MHP terminal
	 * detects that the time interval allowed by the present document for such
	 * new descriptors has elapsed. Where an NPT value is unknown or cannot be computed, -1 shall be used.
	 * @param source the stream whose NPT suffered a discontinuity
	 * @param before the last NPT value detected before the discontinuity
	 * @param after the first NPT value detected after the discontinuity
	 */
	public NPTDiscontinuityEvent( DSMCCStream source, long before, long after )
	{super(source);}

	/**
	 * Return the last known stable value of NPT before the discontinuity
	 * @return an NPT value
	 */	
	public long getLastNPT() { return 0;}

	/**
	 * Return the first known stable value of NPT after the discontinuity
	 * @return an NPT value
	 */	
	public long getFirstNPT() { return 0;}

}

