/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.dvb.media;



import org.havi.ui.HScreenPoint;



/**

 * VideoTransformation objects express video transformations, i.e.

 * the clipping, the horizontal and vertical scaling and the position

 * of the video.

 * All transformations are to be applied after possible ETR154 up-sampling.

 * <p>

 * Note: Instances of VideoTransformation can represent pan and scan, but

 * an application cannot create such instances itself. An application

 * can get a VideoTransformation representing pan and scan, by calling

 * the VideoFormatControl.getVideoTransformation() method with the

 * pan and scan Decoder Format Conversion constant.

 */



public class VideoTransformation

{

	/**

	 * Creates a VideoTransformation object with default parameters.

	 * Clipping is disabled, both the horizontal and the vertical

	 * scaling factors are 1, and the video position is (0,0) in the 

	 * normalised coordinate space.

	 */

	public VideoTransformation()

	{

	}

	

	/**

	 * Creates a VideoTransformation object with the supplied

	 * parameters.

	 * 

	 * @param clipRect the bounding box of the clipping region. The coordinate

	 * space used to express the region is that of the decoded video after possible

	 * ETR154 up-sampling. A non-null ClipRect enables clipping. A null ClipRect disables it.

	 * 

	 * @param horizontalScalingFactor the horizontal scaling factor.

	 * @param verticalScalingFactor the vertical scaling factor.

	 * @param location the location of the video on the screen in the

	 * normalised coordinate space.

	 */

	public VideoTransformation(java.awt.Rectangle clipRect,

							   float horizontalScalingFactor,

							   float verticalScalingFactor,

							   HScreenPoint location)

	{

	}

	

	/**

	 * Sets the clipping region.

	 * <p>

	 * If this video transformation represents pan and scan, then it will

	 * no longer represent pan and scan when this method is called.

	 * A non-null ClipRect enables clipping. A null ClipRect disables it.

	 * 

	 * @param clipRect the bounding box of the clipping region. The coordinate

	 * space used to express the region is that of the decoded video after possible

	 * ETR154 up-sampling.

	 */

	public void setClipRegion(java.awt.Rectangle clipRect)

	{

	}

	

	/**

	 * Gets the clipping region.

	 * 

	 * @return the bounding box of the clipping region. The coordinate space

	 * used to express the region is that of the decoded video after possible

	 * ETR154 up-sampling. null is returned if this video transformation

	 * represents pan and scan or if clipping is disabled.

	 */

	public java.awt.Rectangle getClipRegion()

	{

		return null;

	}

	

	/**

	 * Sets the horizontal and vertical scaling factors.

	 * 

	 * @param horizontalScalingFactor the horizontal scaling factor.

	 * @param verticalScalingFactor the vertical scaling factor.

	 */

	public void setScalingFactors(float horizontalScalingFactor,

								  float verticalScalingFactor)

	{

	}

	

	/**

	 * Gets the horizontal and vertical scaling factors.

	 * 

	 * @return an array with two elements. The first element contains

	 * the horizontal scaling factor, the second element the vertical

	 * scaling factor.

	 */

	public float[] getScalingFactors()

	{

		return null;

	}

	

	/**

	 * Sets the video position.

	 * 

	 * @param location the location of the video on the screen in the

	 * normalised coordinate space.

	 */

	public void setVideoPosition(HScreenPoint location)

	{

	}

	

	/**

	 * Returns the video position.

	 * 

	 * @return the location of the video on the screen in the normalised

	 * coordinate space.

	 */

	public HScreenPoint getVideoPosition()

	{

		return null;

	}

	

	/**

	 * Returns whether this video transformation represents pan and scan.

	 * 

	 * @return true is this video transformation represents pan and scan,

	 * false otherwise.

	 */

	public boolean isPanAndScan()

	{

		return false;

	}

}


