/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.havi.ui.event;





import java.awt.Component;





/**

 * An {@link org.havi.ui.event.HKeyEvent HKeyEvent} event is used to

 * interact with a component implementing the {@link

 * org.havi.ui.HKeyboardInputPreferred HKeyboardInputPreferred} interface

 * as follows:

 *

 * <p><ul>

 *

 * <li> An {@link org.havi.ui.event.HKeyEvent HKeyEvent} event may be sent

 * from the HAVi system to inform the component about key-input. The source

 * of the input may be either a real or a virtual keyboard.

 * 

 * <li> An {@link org.havi.ui.event.HKeyEvent HKeyEvent} event is sent from

 * the component to all registered {@link

 * org.havi.ui.event.HKeyListener HKeyListeners} whenever the

 * component received input.

 * 

 * </ul><p>

 * 

 * All interoperable HAVi components which expect to receive {@link

 * org.havi.ui.event.HKeyEvent HKeyEvent} events must either implement the

 * {@link org.havi.ui.HKeyboardInputPreferred

 * HKeyboardInputPreferred} interface or subclass components providing

 * the <code>processHKeyEvent({@link

 * org.havi.ui.event.HKeyEvent HKeyEvent})</code> method.

 * 

 * <hr>

 * The parameters to the constructors are as follows, in cases where

 * parameters are not used, then the constructor should use the default

 * values.

 * <p>

 * <h3>Default parameter values exposed in the constructors</h3>

 * <table border>

 * <tr><th>Parameter</th><th>Description</th><th>Default value</th>

 * <th>Set method</th><th>Get method</th></tr>

 * <tr><td colspan=5>None.</td></tr>

 * </table>

 * <h3>Default parameter values not exposed in the constructors</h3>

 * <table border>

 * <tr><th>Description</th><th>Default value</th><th>Set method</th>

 * <th>Get method</th></tr>

 * <tr><td colspan=4>None.</td></tr>

 * </table>

 *

 * @see org.havi.ui.HKeyboardInputPreferred#processHKeyEvent(org.havi.ui.event.HKeyEvent)

 */

public class HKeyEvent extends HRcEvent

{



  /**

   * Constructs an {@link org.havi.ui.event.HKeyEvent HKeyEvent}

   * object with the specified source component, type, modifiers and

   * key.

   *

   * @param source the object where the event originated.

   * @param id This is the value that will be returned by the event

   * object's <code>getID()</code> method.

   * @param when the time stamp for this event.

   * @param modifiers indication of any modification keys that are

   * active for this event.

   * @param keyCode the code of the key associated with this event.

   * @param keyChar the character representation of the key

   * associated with this event.

   */

  public HKeyEvent(Component source, int id, long when, int modifiers,

                   int keyCode, char keyChar) {

    super(source, id, when, modifiers, keyCode, keyChar);

  }



  

  /**

   * Constructs an {@link org.havi.ui.event.HKeyEvent HKeyEvent}

   * object with the specified source component, type, modifiers and

   * key.

   *

   * @param source the object where the event originated.

   * @param id This is the value that will be returned by the event

   * object's <code>getID()</code> method.

   * @param when the time stamp for this event.

   * @param modifiers indication of any modification keys that are

   * active for this event.

   * @param keyCode the code of the key associated with this event.

   * @deprecated See explanation in java.awt.event.KeyEvent.

   */

  public HKeyEvent(Component source, int id, long when, int modifiers,

                   int keyCode) {

    super(source, id, when, modifiers, keyCode);

  }



}




