/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.davic.resources;



/**

 * This interface should be implemented by objects that use a scarce resource.

 */



public interface ResourceClient

{

  /**
   * A call to this operation informs the ResourceClient that another 
   * ResourceClient instance has requested the resource accessed via the proxy parameter.
   * If the ResourceClient decides to give up the resource as a result of this,

   * it should terminate its usage of proxy and return True, otherwise False. 

   * requestData may be used to pass more data to the ResourceClient so that 

   * it can decide whether or not to give up the resource, using semantics 

   * specified outside this framework;  for conformance to this framework, 

   * requestData can be ignored by the ResourceClient.

   *

   * @param proxy the ResourceProxy representing the scarce resource to the application

   * @param requestData application specific data

   * @return If the ResourceClient decides to give up the resource following

   * this call, it should terminate its usage of proxy and return True, 

   * otherwise False. 

   */



  public abstract boolean requestRelease(ResourceProxy proxy, Object requestData);



  /**

   * A call to this operation informs the ResourceClient that proxy is about 

   * to lose access to a resource. The ResourceClient shall complete any 

   * clean-up that is needed before the resource is lost before it returns

   * from this operation. This operation is not guaranteed to be allowed to 

   * complete before notifyRelease() is called. 

   * @param proxy the ResourceProxy representing the scarce resource to the application

   */



  public abstract void release(ResourceProxy proxy);



  /**

   * A call to this operation notifies the ResourceClient that proxy has lost 

   * access to a resource. This can happen for two reasons:  either the 

   * resource is unavailable for some reason beyond the control of the 

   * environment (e.g. hardware failure) or because the client has been too 

   * long in dealing with a ResourceClient.release() call.

   *

   * @param proxy the ResourceProxy representing the scarce resource to the application

   *

   */



  public abstract void notifyRelease(ResourceProxy proxy);

}




