/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.dvb.application;

/**
 * The <code>AppsDatabaseEvent</code> class indicates either an entry
 * in the application database has changed, or so many changes have occurred.
 * that the database should be considered totally new.
 * An event with event_id NEW_DATABASE shall always be sent after switching to a new service.
 * After such an event, the contents of the database (both the set of applications and 
 * their attributes) shall reflect the new database contents. All former contents of 
 * the database shall be discarded except for running externally authorised applications.
 * It is platform dependant if and when a new database event is thrown 
 * while tuned to the same service except that a NEW_DATABASE event shall not 
 * be sent when only one application has changed within a service.
 * <p>The APP_ADDED, APP_CHANGED and APP_DELETED events shall not be 
 * generated in response to the same database change as caused a 
 * NEW_DATABASE event to be generated.
 * <p>
 * @since   MHP1.0
 */
public class AppsDatabaseEvent extends java.util.EventObject{
    /**
     * The new database event id.
     */
    static public final int NEW_DATABASE = 0;
    /**
     * The changed event id. The APP_CHANGED event is generated whenever
     * any of the information about an application changes. It is NOT generated
     * when the entry is added to or removed from the AppsDatabase. In such cases, 
     * the APP_ADDED or APP_DELETED events will be generated instead.
     */
    static public final int APP_CHANGED = 1;
    /**
     * The addition event id. The APP_ADDED event is generated whenever
     * an entry is added to the AppsDatabase. It is NOT generated
     * when the entry already in the AppsDatabase changes. 
     */
    static public final int APP_ADDED = 2;
    /**
     * The deletion event id. The APP_DELETED event is generated whenever
     * an entry is removed from the AppsDatabase. 
     */
    static public final int APP_DELETED = 3;

    /**
     * Create a new AppsDatabaseEvent object for the entry in the database 
     * that changed, or for a new database. 
     * <p>    
     * @param id the cause of the event
     * @param appid the AppId of the entry that changed
     * @param source the AppaDatabase object.
     * @since   MHP1.0
     */

     public AppsDatabaseEvent(int id, AppID appid, Object source){super(source);};

    /**
     * gets the application ID object for the entry in the database that 
     * changed.
     * <p>    
     * When the event type is NEW_DATABASE, AppID will be null.
     * @return     application ID representing the application
     * @since   MHP1.0
     */
    public AppID getAppID(){return null;}

    /**
     * gets the type of the event.
     * <p>    
     * @return  an integer that matches one of the static fields describing events.
     * @since   MHP1.0
     */
    public int getEventId(){return 0;}


}
	

