/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/

package org.dvb.dsmcc;

import java.util.*;

/** 
  * This class describes a Stream event which is used to synchronize
  * an application with an MPEG Stream. 
  * NOTE: The NPT mechanism and scheduled stream events that depend on it 
  * are known to be vulnerable to disruption in many digital TV distribution 
  * networks. Existing deployed network equipment that re-generates the STC 
  * is unlikely to be aware of NPT and hence will not make the necessary 
  * corresponding modification to STC values inside NPT reference descriptors.
  * This may cause scheduled stream events to fire at the wrong time or to 
  * never fire at all. Applications should only use scheduled stream events 
  * where they are confident that the network where they are to be used does 
  * not have this problem.
  */

public class StreamEvent extends java.util.EventObject {


	/**
	 * Creates a StreamEvent object.	
	 *
	 * @param source The <code>DSMCCStreamEvent</code> that has generated the event. 
 	 * @param npt The value of the NPT (Normal Play Time) when the event is triggered. This 
 	 * value is equal to the field eventNPT in the DSMCC StreamEventDescriptor except where 
	 * the event is a "do it now" event in which case the value -1 is returned (as the value 
	 * of NPT may not be meaningful). 
	 * @param name The name of this event. The list of event names is located in the DSMCC 
	 * StreamEvent object. This list is returned by the method <code>DSMCCStreamEvent.getEventList</code>.
	 * @param eventId The eventId of this event. The list of event IDs is located in the 
	 * DSMCC StreamEvent object. 
	 * @param eventData The application specific data found in the DSMCC StreamEventDescriptor. 
	 */
	public StreamEvent(DSMCCStreamEvent source, long npt, String name, int eventId, byte[] eventData)
	{super(source);
	}
  
	/**
	 * This method returns the DSMCCStreamEvent that generated the event.
         *
	 * @return the DSMCCStreamEvent that generated the event.
	 */ 
	public java.lang.Object getSource() {return null;}



  /** 
	* This method is used to get the name of the StreamEvent 
	* @return the name of the StreamEvent 
	*/
  public String getEventName()
	{ return null;
	}
  
  /** 
	* This method is used to get the identifier of the StreamEvent.
	* @return The identifier of the StreamEvent.
	*/
  public int getEventId()
	{ return 0;
	}
  
  /**
	* This method is used to get the NPT of the Event in milliseconds.
	* @return The NPT of the Event in milliseconds.
	*/
  public long getEventNPT()
	{ return (long) 0;
	}
  
  /**
	* This method is used to retrieve the private data associated
	* with the event.
	* @return The private data associated with the event.
	*/
  public byte[] getEventData()
	{ return null;
	}

}

