/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.dvb.ui;

import java.io.IOException;

/**
 * Provides a mechanism for applications to instantiate fonts that
 * are not built into the system.
 * The two constructors of this class allow fonts to be downloaded either through 
 * the font index file of the application or directly from a font file in the 
 * format(s) specified in the main body of the present document.
 **/

public class FontFactory {
    /**
     * Constructs a FontFactory for the font index file bound to this application
     * in the application signalling. The call to the constructor is synchronous
     * and shall block until the font index file has been retrieved or an 
     * an exception is thrown.
     *
     *  @throws FontFormatException if there is an error in the font index
     *      file bound with the application.
     *  @throws IOException  if there is no font index file bound
     *       with the application, or if there is an
     *       error attempting to access the data in that
     *       file.
     **/
    public FontFactory() throws FontFormatException, IOException {
    }


    /**
     * Constructs a FontFactory for the font file found at the given location.
     * The call to the constructor is synchronous
     * and shall block until the font file has been retrieved or an exception
     * is thrown.
     *
     *  @param u  The location of the font file
     *
     *  @throws IOException  if there is an
     *       error attempting to access the data referenced
     *       by the URL
     *  @throws IllegalArgumentException if the URL is not both valid and supported
     *  @throws SecurityException    if access to the specified URL is denied by
     *       security policy
     *  @throws FontFormatException  if the file at that URL is not a valid
     *      font file as specified in the main body of the present document
     *
     **/
    public FontFactory(java.net.URL u) throws IOException,
       FontFormatException
		    
    {
    }


    /** 
     * Creates a font object from the font source associated with this
     * FontFactory. This font will remain valid even if the FontFactory
     * is no longer reachable from application code. The name returned
     * by Font.getName() might not be the same as the name supplied, for example,
     * it might have a string prepended to it that identifies the source FontFactory
     * in a platform-dependant manner. For FontFactory instances bound to the
     * font index file of an application, the call to the method is synchronous and
     * shall block until either an exception is thrown or any required network access
     * has completed.
     * <p>
     * The value of the style argument must be as defined in java.awt.Font.
     * Valid values are the following:
     *   <ul>
     * <li><code>java.awt.Font.PLAIN</code>
     * <li><code>java.awt.Font.BOLD</code>
     * <li><code>java.awt.Font.ITALIC</code>
     * <li><code>java.awt.Font.BOLD + java.awt.Font.ITALIC</code>
     *   </ul>
     *
     * @param name the font name
     * @param style the constant style used, such as java.awt.Font.PLAIN.
     * @param size the point size of the font
     *
     * @throws FontNotAvailableException  if a font with given parameters cannot
     *        be located or created.
     * @throws IOException if there is an error retrieving a font from the
     * network. Thrown only for font factory instances bound to the font index file of
     * an application.
     * @throws IllegalArgumentException   if the style parameter is not in the
     *        set of valid values, or if the size parameter
     *        is zero or negative.
     *  @throws FontFormatException  if the font file is not a valid 
     *      font file as specified in the main body of the present document.
     *      Thrown only for font factory instances bound to the font index file
     *      of an application.
     **/
    public java.awt.Font createFont(String name, int style, int size) 
    throws FontNotAvailableException,FontFormatException, IOException {
	return null;
    }
}

