/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.havi.ui;

/*
 * Copyright 2000-2003 by HAVi, Inc. Java is a trademark of Sun
 * Microsystems, Inc. All rights reserved.  
 */


/**
 * A component which implements <code>HAdjustmentInputPreferred</code>
 * indicates that this component expects to receive {@link
 * org.havi.ui.event.HAdjustmentEvent} input events.
 * <p>
 * The system must provide a means of generating
 * <code>HAdjustmentEvent</code> events as
 * necessary.  For platforms with a restricted number of physical keys
 * this may involve a &quot;virtual keyboard&quot; or similar
 * mechanism. The system might use the information returned by the method
 * {@link HOrientable#getOrientation} of the super interface to select
 * appropriate key mappings for this event. The mechanisms to generate
 * this event shall not be effective while the component is disabled
 * (see {@link HComponent#setEnabled}).
 * <p>
 * Widgets of HAVi compliant applications implementing the
 * <code>HAdjustmentInputPreferred</code> interface must have {@link HComponent} in their
 * inheritance tree.
 * <p>
 * Note that the <code>java.awt.Component</code> method
 * <code>isFocusTraversable</code> shall always return true for a
 * <code>java.awt.Component</code> implementing this interface.  
 */
public interface HAdjustmentInputPreferred extends HOrientable
{
    /**
     * Get the adjustment mode for this
     * <code>HAdjustmentInputPreferred</code>. If the returned value is <code>true</code> the
     * component is in adjustment mode, and its value may be changed on
     * receipt of {@link org.havi.ui.event.HAdjustmentEvent#ADJUST_LESS} and
     * {@link org.havi.ui.event.HAdjustmentEvent#ADJUST_MORE} events.
     * <p>
     * The component is switched into and out of adjustment mode on
     * receiving {@link org.havi.ui.event.HAdjustmentEvent#ADJUST_START_CHANGE}
     * {@link org.havi.ui.event.HAdjustmentEvent#ADJUST_END_CHANGE}
     * events. Note that these events are ignored, if the component is
     * disabled.
     * 
     * @return true if this component is in adjustment mode, false
     * otherwise.
     * @see HComponent#setEnabled
     */
    public boolean getAdjustMode();

    /**
     * Set the adjustment mode for this <code>HAdjustmentInputPreferred</code>.
     * <p>
     * This method is provided for the convenience of component
     * implementors. Interoperable applications shall not call this
     * method. It cannot be made protected because interfaces cannot have
     * protected methods.
     * <p>
     * Calls to this method shall be ignored, if the component is
     * disabled.
     * 
     * @param adjust true to switch this component into adjustment mode,
     * false otherwise.
     * @see HAdjustmentInputPreferred#getAdjustMode 
     * @see HComponent#setEnabled
     */
    public void setAdjustMode(boolean adjust);

    /**
     * Process an <code>HAdjustmentEvent</code>
     * sent to this <code>HAdjustmentInputPreferred</code>.
     * Widgets implementing this interface
     * shall ignore <code>HAdjustmentEvents</code>, while the
     * component is disabled.
     * 
     * @param evt the <code>HAdjustmentEvent</code> to process.
     * @see HComponent#setEnabled
     */
    public void processHAdjustmentEvent(org.havi.ui.event.HAdjustmentEvent evt);
}









