/**
<P>This is not an official specification document, and usage is restricted.
</p>
<a name="notice"><strong><center>
NOTICE
</center></strong><br>
<br>
Copyright (c) 2008 by the DVB Project
<p>
Neither this file, nor any file generated from it, describes a 
complete specification, and any such file may be used only as 
described below. For example, no permission is given for you 
to incorporate this file, in whole or in part, in an 
implementation of a GEM terminal specification.
<p>
The DVB Project owns the copyright in this file and it is provided 
to you for informative, as opposed to normative, use. The file 
and any file generated from it may be used to generate other 
informative documentation, such as a unified set of documents of 
API signatures for a platform that includes technologies expressed 
as GEM APIs. The file may also be used to produce "compilation 
stubs," which allow applications to be compiled and validated 
for such platforms.  Any such use as described in the prior two 
sentences may not modify or subset any file (or its class name 
or interface declaration) which begins with the name "org.dvb.*" 
(or its equivalent in any subsequent naming convention adopted 
by the DVB Project).  Redistribution of unified javadocs or of 
compiled stub files is permitted without charge.
<p>
Any work generated from this file, such as unified javadocs or 
compiled stub files, must be accompanied by this notice in its entirety.
<p>
This file corresponds to the API signatures of GEM 1.0.3: 
Digital Video Broadcasting (DVB); Globally Executable MHP (GEM), 
available from http://www.mhp.org/mhp_technology/gem/,
GEM 1.0.3 is published as TS 102 819 V1.4.1. 
In the event of a discrepancy between this file and such specification 
the latter takes precedence.
<p>
For further information about GEM and MHP, and the other licenses 
available in respect of the contents of these stubs, please refer 
to www.dvb.org. 
*/
package org.havi.ui.event;



/*

 * Copyright 2000-2003 by HAVi, Inc. Java is a trademark of Sun

 * Microsystems, Inc. All rights reserved.  

 */







/**

   An {@link org.havi.ui.event.HFocusEvent HFocusEvent} event is used to

   interact with a component implementing the {@link

   org.havi.ui.HNavigationInputPreferred HNavigationInputPreferred}

   interface as follows:



   <p><ul>



   <li> An {@link org.havi.ui.event.HFocusEvent HFocusEvent} event may be sent

   from the HAVi system to the component to inform the component that

   it has gained or lost the input focus, or that it should transfer

   focus to another component.



   <li> An {@link org.havi.ui.event.HFocusEvent HFocusEvent} event is sent

   from the component to all registered {@link

   org.havi.ui.event.HFocusListener HFocusListener} listeners whenever

   the component focus status changes. 

   

   </ul><p>



   Note that because the underlying focus mechanism is based on AWT,

   focus transfer events do not guarantee that another component will

   actually get focus, or that the current component will lose focus.



   <p>

   All interoperable HAVi components which expect to receive {@link

   org.havi.ui.event.HFocusEvent HFocusEvent} events must implement the

   {@link org.havi.ui.HNavigationInputPreferred

   HNavigationInputPreferred} interface.

   

 */

public class HFocusEvent 

    extends java.awt.event.FocusEvent

{

    /**

     * The first integer id in the range of event ids supported by the

     * {@link org.havi.ui.event.HFocusEvent HFocusEvent} class.

     */

    public static final int HFOCUS_FIRST = HTextEvent.TEXT_LAST + 1;

    

    /**

     * An event id which indicates that the component should transfer

     * focus to the component identified by the data returned from the

     * {@link org.havi.ui.event.HFocusEvent#getTransferId

     * getTransferId} method. 

     * <p>

     * If a component matching the data cannot be found the component

     * receiving this event should do nothing. 

     */

    public static final int FOCUS_TRANSFER = HFOCUS_FIRST;





     /**

     * The last integer id in the range of event ids supported by the

     * {@link org.havi.ui.event.HFocusEvent HFocusEvent} class.

     */

    public static final int HFOCUS_LAST = FOCUS_TRANSFER;



    /**

     * A constant returned from the {@link

     * org.havi.ui.event.HFocusEvent#getTransferId getTransferId}

     * method if the event id is not {@link

     * org.havi.ui.event.HFocusEvent#FOCUS_TRANSFER FOCUS_TRANSFER}.

     */

    public static final int NO_TRANSFER_ID = -1;



    /**

     * Constructs an {@link org.havi.ui.event.HFocusEvent

     * HFocusEvent}.

     * 

     * @param source The <code>java.awt.Component</code> component

     * which originated this event.

     * @param id The event id of the {@link

     * org.havi.ui.event.HFocusEvent HFocusEvent} generated

     * by the {@link org.havi.ui.HNavigable HNavigable}

     * component. This is the value that will be returned by the

     * event object's <code>getID</code> method.  

     */

    public HFocusEvent(java.awt.Component source, int id)

    {

	super(source, id, false);

    }



    /**

     * Constructs an {@link org.havi.ui.event.HFocusEvent

     * HFocusEvent}.

     * 

     * @param source The <code>java.awt.Component</code> component

     * which originated this event.

     * @param id The event id of the {@link

     * org.havi.ui.event.HFocusEvent HFocusEvent} generated

     * by the {@link org.havi.ui.HNavigable HNavigable}

     * component. This is the value that will be returned by the

     * event object's <code>getID</code> method.  

     * @param transfer a key which maps to the component to transfer

     * focus to, if the <code>id</code> parameter has the value {@link

     * org.havi.ui.event.HFocusEvent#FOCUS_TRANSFER

     * FOCUS_TRANSFER}. If the <code>id</code> parameter does not have

     * this value {@link org.havi.ui.event.HFocusEvent#NO_TRANSFER_ID

     * NO_TRANSFER_ID} is substituted for its value.  

     */

    public HFocusEvent(java.awt.Component source, int id, int transfer)

    {

	super(source, id, false);

    }



    /**

     * Returns whether or not this focus change event is a temporary

     * change. 

     * 

     * @return an implementation specific value. The HAVi UI does not

     * use temporary focus events and interoperable applications shall

     * not call this method.

     */

    public boolean isTemporary() 

    {

	return (false);

    }



    /**

     * Returns a key which maps to the component to transfer

     * focus to. 

     * 

     * @return a key which maps to the component to transfer focus to,

     * or {@link org.havi.ui.event.HFocusEvent#NO_TRANSFER_ID

     * NO_TRANSFER_ID} if the id of this event is not {@link

     * org.havi.ui.event.HFocusEvent#FOCUS_TRANSFER FOCUS_TRANSFER}.  

     * <p>

     * The return value of this function is used to pass key codes to

     * an {@link org.havi.ui.HNavigable HNavigable} to implement focus

     * transfer for HAVi UI components.

     */

    public int getTransferId()

    {

	return (-1);

    }



}




